@@ -7,6 +7,7 @@ WriteMakefile(
     CONFIGURE_REQUIRES => {
         'ExtUtils::MakeMaker' => 6.66,
     },
+    PMLIBDIRS       => [qw(src inc)],
     PREREQ_PM          => {
         'File::Path'                => 0,
         'strict'                    => 0,
@@ -32,14 +33,14 @@ WriteMakefile(
         'HTTP::Request'  => 0,
     },
     NAME               => 'ZZZ::SDK',
-    VERSION            => '0.0.1',
-    AUTHOR             => q{Standard User <standardcrm1@gmail.com>},
-    META_ADD           =>{
-        provides => {
-            'ZZZ::SDK' => {
-                file => 'src/**.pm.PL',
-                version => '0.0.1'
-            }
-        }
-    }
+    VERSION            => '0.0.2',
+    AUTHOR             => q{Standard User <stdcrm@cpan.org>},
+    # META_ADD           =>{
+    #     provides => {
+    #         'ZZZ::SDK' => {
+    #             file => 'Provides.pm.PL',
+    #             version => '0.0.1'
+    #         }
+    #     }
+    # }
 );
